@@ -1,20 +1,43 @@
 package Bio::MLST::DatabaseSettings;
 # ABSTRACT: Read in an XML file of settings and return a hash with the values.
-$Bio::MLST::DatabaseSettings::VERSION = '2.1.1630910';
-
-
+$Bio::MLST::DatabaseSettings::VERSION = '2.1.1706216';
 
 use Moose;
 use XML::LibXML;
+use LWP::UserAgent;
+use HTTP::Request;
 
 has 'filename'          => ( is => 'ro', isa => 'Str', required => 1 );
 
+sub generate_dom
+{
+	my($self, $location ) = @_;
+	
+	# local file and remote files need to be treated differently
+	if ( !( $location =~ /(http|ftp)/ ) ) {
+		return XML::LibXML->load_xml( location => $location );	
+	}
+	else
+	{
+		# its a remote file so download content
+	        my $ua = LWP::UserAgent->new;
+		if(defined($ENV{HTTPS_PROXY}))
+		{
+	        	$ua->proxy( [ 'http', 'https' ], $ENV{HTTPS_PROXY} );
+		}
+	        my $req = HTTP::Request->new( GET => $location );
+	        my $res = $ua->request($req);
+	        $res->is_success or die "Could not connect to $location\n";
+		XML::LibXML->load_xml( string => $res->content );
+	}
+}
+
 sub settings
 {
   my($self) = @_;
   my %databases_attributes;
   
-  my $dom = XML::LibXML->load_xml( location => $self->filename );
+  my $dom = $self->generate_dom($self->filename);
   
   for my $species ($dom->findnodes('/data/species')) 
   {
@@ -59,7 +82,7 @@ Bio::MLST::DatabaseSettings - Read in an XML file of settings and return a hash
 
 =head1 VERSION
 
-version 2.1.1630910
+version 2.1.1706216
 
 =head1 SYNOPSIS
 
